@@ -1,16 +1,16 @@
-#$Id: Batch.pm 291 2013-11-22 02:17:32Z maj $
+#$Id: Batch.pm 347 2014-02-12 02:47:40Z maj $
 package REST::Neo4p::Batch;
 use REST::Neo4p::Exceptions;
 use JSON::Streaming::Reader;
 require REST::Neo4p;
 
 use base qw(Exporter);
-use strict;
-use warnings;
+#use strict;
+#use warnings;
 no warnings qw(once);
 
 BEGIN {
-  $REST::Neo4p::Batch::VERSION = '0.2001';
+  $REST::Neo4p::Batch::VERSION = '0.2240';
 }
 
 our @EXPORT = qw(batch);
@@ -22,6 +22,7 @@ sub batch (&@) {
   my @errors;
   REST::Neo4p::CommException->throw("Not connected\n") unless REST::Neo4p->connected;
   warn 'Agent already in batch_mode on batch() call' if ($agent->batch_mode);
+  REST::Neo4p::LocalException->throw("batch requires argument 'keep_objs' or 'discard_objs'\n") unless ($action && grep(/^$action$/,qw/keep_objs discard_objs/));
   $agent->batch_mode(1);
   $coderef->();
   for ($action) {
@@ -276,7 +277,7 @@ L<REST::Neo4p>, L<REST::Neo4p::Agent>
 
 =head1 LICENSE
 
-Copyright (c) 2012-2013 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012-2014 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
