@@ -1,4 +1,4 @@
-#$Id: Entity.pm 317 2013-12-30 20:39:25Z maj $
+#$Id: Entity.pm 348 2014-02-13 05:05:44Z maj $
 use v5.10;
 package REST::Neo4p::Entity;
 use REST::Neo4p::Exceptions;
@@ -10,7 +10,7 @@ use warnings;
 
 # base class for nodes, relationships, indexes...
 BEGIN {
-  $REST::Neo4p::Entity::VERSION = '0.2230';
+  $REST::Neo4p::Entity::VERSION = '0.2240';
 }
 
 our $ENTITY_TABLE = {};
@@ -137,7 +137,7 @@ sub remove {
   elsif ($e = Exception::Class->caught()) {
     ref $e ? $e->rethrow : die $e;
   }
-  $self->DESTROY;
+  $self->_deregister;
   return 1;
 }
 # set_property( { prop1 => $val1, prop2 => $val2, ... } )
@@ -394,17 +394,21 @@ sub _handle {
   return;
 }
 
+sub _deregister {
+  my $self = shift;
+  my $entity_type = ref $self;
+  $entity_type =~ s/.*::(.*)/\L$1\E/;
+  foreach (sort keys %{$ENTITY_TABLE->{$entity_type}{$$self}}) {
+    delete $ENTITY_TABLE->{$entity_type}{$$self}{$_};
+  }
+  delete $ENTITY_TABLE->{$entity_type}{$$self};
+}
+
 sub DESTROY {
   my $self = shift;
   my $entity_type = ref $self;
   $entity_type =~ s/.*::(.*)/\L$1\E/;
-  foreach (keys %{$ENTITY_TABLE->{$entity_type}{$$self}}) {
-    delete $ENTITY_TABLE->{$entity_type}{$$self}{$_};
-  }
-
-  delete $ENTITY_TABLE->{$entity_type}{$$self};
-
-  return;
+  $self->_deregister if $ENTITY_TABLE->{$entity_type}{$$self}{entity_type};
 }
 
 sub _create_accessors {
@@ -427,7 +431,7 @@ use strict;
 use warnings;
 no warnings qw/once/;
 BEGIN {
-  $REST::Neo4p::Simple::VERSION = '0.2220';
+  $REST::Neo4p::Simple::VERSION = '0.2240';
 }
 
 sub new { $_[1] }
@@ -469,7 +473,7 @@ L<REST::Neo4p::Index>.
 
 =head1 LICENSE
 
-Copyright (c) 2012-2013 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012-2014 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
